@@ -62,4 +62,4 @@ class FulfilmentPointSchema(Schema):
     categories = RelatedResourceField(schema=FulfilmentPointCategorySchema, many=True, missing=[])
     venue = RelatedResourceLinkField(schema=VenueSchema, required=False, missing=None)
     external_id = fields.String(missing=None, data_key='externalId')
-    audiences = RelatedResourceLinkField(schema=AudienceSchema, many=True, missing=[])
+    audiences = fields.List(RelatedResourceLinkField(schema=AudienceSchema, microservice_aware=True), many=True, missing=[])
